Module api_versions

Module api_versions 

Structs

ApiKeyVersion
ApiVersionsRequestV0
ApiVersionsRequestV3
ApiVersions v3 request with client software identification.
ApiVersionsRequestV4
ApiVersions v4 request.
ApiVersionsRequestV5
ApiVersions v5 request with optional cluster and node identity checks.
ApiVersionsResponseV0
ApiVersionsResponseV3
ApiVersions v3 response with flexible encoding and forward-compatible tags.
FinalizedFeature
A cluster-wide finalized feature range from ApiVersions v3+.
SupportedFeature
A feature version range advertised by one broker in ApiVersions v3+.

Constants

API_KEY
UNSUPPORTED_VERSION_ERROR_CODE
Kafka’s UNSUPPORTED_VERSION protocol error code.

Traits

ApiVersionsLookup
Common capability lookup implemented by fixed and flexible ApiVersions responses.

Type Aliases

ApiVersionsResponseV4
ApiVersions v4 response. The body schema is identical to v3.
ApiVersionsResponseV5
ApiVersions v5 response. The body schema is identical to v4.