pub fn encoded_message_set_len(records: &[MessageSetMessage]) -> Result<usize>Expand description
Returns the encoded byte length of a Produce v2 message set.
pub fn encoded_message_set_len(records: &[MessageSetMessage]) -> Result<usize>Returns the encoded byte length of a Produce v2 message set.