pub fn encoded_record_batch_set_len(
records: &[RecordBatchMessage],
) -> Result<usize>Expand description
Returns the encoded byte length of a Produce v3 record batch set.
pub fn encoded_record_batch_set_len(
records: &[RecordBatchMessage],
) -> Result<usize>Returns the encoded byte length of a Produce v3 record batch set.