Module share

Module share 

Structs

ShareAcknowledgePartitionResponseV1
One partition result returned by ShareAcknowledge.
ShareAcknowledgePartitionV1
One partition’s acknowledgement batches.
ShareAcknowledgeRequestV1
ShareAcknowledge v1 request.
ShareAcknowledgeRequestV2
ShareAcknowledge v2 request with KIP-1222 renewal support.
ShareAcknowledgeResponseV1
ShareAcknowledge v1 response.
ShareAcknowledgeResponseV2
ShareAcknowledge v2 response with the current acquisition lock timeout.
ShareAcknowledgeTopicResponseV1
One topic result returned by ShareAcknowledge.
ShareAcknowledgeTopicV1
One topic and its acknowledgement batches in a ShareAcknowledge request.
ShareAcknowledgementBatchV1
One batch of records acknowledged by a share consumer.
ShareAcquiredRecordsV1
Acquired record range returned by ShareFetch.
ShareFetchPartitionResponseV1
One partition returned by ShareFetch.
ShareFetchPartitionV1
Acknowledgement batches for one share-group partition.
ShareFetchRequestV1
ShareFetch v1 request.
ShareFetchRequestV2
ShareFetch v2 request with KIP-1206 acquisition and KIP-1222 renewal fields.
ShareFetchResponseV1
ShareFetch v1 response.
ShareFetchTopicResponseV1
One topic returned by ShareFetch.
ShareFetchTopicV1
One topic in a ShareFetch request.
ShareForgottenTopicV1
A topic and partitions to remove from a share fetch session.
ShareGroupHeartbeatAssignmentV1
Assignment returned by ShareGroupHeartbeat.
ShareGroupHeartbeatRequestV1
ShareGroupHeartbeat v1 request.
ShareGroupHeartbeatResponseV1
ShareGroupHeartbeat v1 response.
ShareLeaderIdAndEpochV1
Current leader information returned for a share partition.
ShareNodeEndpointV1
Broker endpoint returned when a share partition leader changes.
ShareTopicPartitionsV1
A topic and its partition indexes in a share-group assignment.

Constants

SHARE_ACKNOWLEDGE_API_KEY
Kafka ShareAcknowledge API key.
SHARE_FETCH_API_KEY
Kafka ShareFetch API key.
SHARE_GROUP_HEARTBEAT_API_KEY
Kafka ShareGroupHeartbeat API key.