Module streams_group_heartbeat

Module streams_group_heartbeat 

Structs

StreamsGroupHeartbeatCopartitionGroup
A copartition constraint represented by subtopology-level indexes.
StreamsGroupHeartbeatEndpoint
A host and port exposed for Interactive Queries.
StreamsGroupHeartbeatEndpointPartitions
Assignment information grouped by an Interactive Queries endpoint.
StreamsGroupHeartbeatKeyValue
A rack-aware client tag.
StreamsGroupHeartbeatRequestV0
StreamsGroupHeartbeat v0 request.
StreamsGroupHeartbeatResponseV0
StreamsGroupHeartbeat v0 response.
StreamsGroupHeartbeatStatus
A status entry returned by StreamsGroupHeartbeat.
StreamsGroupHeartbeatSubtopology
One subtopology sent while initializing a Streams group.
StreamsGroupHeartbeatTask
A Streams task and its input partitions.
StreamsGroupHeartbeatTaskOffset
A cumulative changelog offset for a Streams task.
StreamsGroupHeartbeatTopic
A topic created or managed by a Streams topology.
StreamsGroupHeartbeatTopicConfig
One topic-level configuration in a Streams topology.
StreamsGroupHeartbeatTopicPartitions
Topic partitions materialized by one Interactive Queries endpoint.
StreamsGroupHeartbeatTopology
A Kafka Streams topology sent while initializing a Streams group.

Constants

API_KEY
Kafka StreamsGroupHeartbeat API key.