pub struct DecodeLimits { /* private fields */ }Expand description
Resource limits applied while decoding broker responses.
Implementations
Sourceimpl DecodeLimits
impl DecodeLimits
Sourcepub const DEFAULT_MAX_ARRAY_ELEMENTS: usize = 1_000_000
pub const DEFAULT_MAX_ARRAY_ELEMENTS: usize = 1_000_000
Default maximum number of elements in one decoded Kafka array.
Sourcepub const DEFAULT_MAX_DECOMPRESSED_RECORD_BYTES: usize
pub const DEFAULT_MAX_DECOMPRESSED_RECORD_BYTES: usize
Default maximum uncompressed size of one Kafka record batch.
Sourcepub const fn with_max_array_elements(self, max: usize) -> Self
pub const fn with_max_array_elements(self, max: usize) -> Self
Sets the maximum number of elements in one decoded Kafka array.
Sourcepub const fn with_max_decompressed_record_bytes(self, max: usize) -> Self
pub const fn with_max_decompressed_record_bytes(self, max: usize) -> Self
Sets the maximum uncompressed size of one Kafka record batch.
Sourcepub const fn max_array_elements(self) -> usize
pub const fn max_array_elements(self) -> usize
Returns the maximum number of elements in one decoded Kafka array.
Sourcepub const fn max_decompressed_record_bytes(self) -> usize
pub const fn max_decompressed_record_bytes(self) -> usize
Returns the maximum uncompressed size of one Kafka record batch.